/*
  Test of Buttons on the 328 2560 CPU S100 CPU Board
  John Monahan    S100Computers.com     4/21/2018
 
  The CPU will use Rx3, Dx3.
*/

#include <LiquidCrystal.h>
#include <EEPROM.h>

LiquidCrystal lcd(42,47,43,44,45,46);         // CPU pins 42,37,41,40,38,38 (PL7, PL2, PL6, PL5, PL4, PL3)

#define READ_LED 3                            // PE4 CPU pin 6 to LED D2  (GREEN)
#define WRITE_LED 2                           // PE5 CPU pin 7 to LED D3  (RED)  
#define ANALOG_INPUT 59                       // PF5 CPU pin 97 to Switches

#define KEY_SW1           1
#define KEY_SW2           2
#define KEY_SW3           3
#define KEY_SW4           4
#define KEY_NOT_PRESSED   127
unsigned char key;
int AnalogIn;
 
void setup() {
  pinMode(READ_LED, OUTPUT);                  // RED
  pinMode(WRITE_LED, OUTPUT);                 // GREEN

  lcd.begin(16,2);
  lcd.clear();
  lcd.setCursor(0,0);
  lcd.print("Buttons Test ");  
  digitalWrite(WRITE_LED, HIGH);        
  digitalWrite(READ_LED, HIGH);        
  delay(1000);
}


void loop() 
  {  
  do {                                                       // wait for a button
     AnalogIn = analogRead(ANALOG_INPUT);
     delay(10);
     } while(abs(AnalogIn - analogRead(ANALOG_INPUT)) > 8);   // wait until reading does not change

    key = KEY_NOT_PRESSED;
    
    if(AnalogIn < 896) key = KEY_SW1;
    if(AnalogIn < 640) key = KEY_SW2;
    if(AnalogIn < 384) key = KEY_SW3;
    if(AnalogIn < 128) key = KEY_SW4;

    switch(key)
        {
        case KEY_SW1:
                  lcd.clear();
                  lcd.setCursor(0,0);
                  lcd.print("SW1 Pressed ");  
                  digitalWrite(WRITE_LED, LOW);        
                  delay(100);
                  digitalWrite(WRITE_LED, HIGH); 
                  break;
         case KEY_SW2:
                  lcd.clear();
                  lcd.setCursor(0,0);
                  lcd.print("SW2 Pressed ");  
                  digitalWrite(WRITE_LED, LOW);        
                  delay(100);
                  digitalWrite(WRITE_LED, HIGH); 
                  break;
          case KEY_SW3:
                  lcd.clear();
                  lcd.setCursor(0,0);
                  lcd.print("SW3 Pressed ");  
                  digitalWrite(WRITE_LED, LOW);        
                  delay(100);
                  digitalWrite(WRITE_LED, HIGH); 
                  break;
       case KEY_SW4:
                  lcd.clear();
                  lcd.setCursor(0,0);
                  lcd.print("SW4 Pressed ");  
                  digitalWrite(WRITE_LED, LOW);        
                  delay(100);
                  digitalWrite(WRITE_LED, HIGH); 
                  break;
          default:
                  lcd.clear();
                  lcd.setCursor(0,0);
                  lcd.print("Unknown key ");  
                  digitalWrite(WRITE_LED, LOW);        
                  delay(100);
                  digitalWrite(WRITE_LED, HIGH); 
                  break;
         }
  }
