/*
  Test of RS232 Interface on the 328 2560 CPU S100 CPU Board using 328 CPU and J1 RS232 port.
  Note can still upload code with USB serial connection. 
  Since there is only one serial connection with the 328 CPU (Rx & Tx), when you have the code loaded
  power down the S100 system. 
  Jumper P41 pin 5 to pin2  and P47 pin 5 to pin 2 to redirect the serial I/O.
  Be sure you have P1 jumpered 1-3 & 2-4 if you are using the actual RS232 J1 socket.
  Set your PC TTY terminal to 115200, No parity, 1 stop bit.
  Upon power on you should see:-
  "Initialized the RS232 Serial Interface to 115200 Baud"
  "Type Characters on PC TTY terminal. They should echo back"

  To reload/upload code return P41 to 4-5 and P47 to 4-5
  
  John Monahan    S100Computers.com     6/23/2018
*/


#include <LiquidCrystal.h>
#include <EEPROM.h>
#include <SoftwareSerial.h>
#include <SPI.h>

LiquidCrystal lcd(8, 9, 7, 6, 5, 4);          // CPU pins 14, 15, 6, 11, 12, 13  (PB0, PB1, PD7, PD6, PD5, PD4 of CPU)
int x = 0;

#define READ_LED 3                            // PE4 CPU pin 6 to LED D2  (GREEN)
#define WRITE_LED 2                           // PE5 CPU pin 7 to LED D3  (RED)  
#define Rx 0                                  // PD0 CPU pin 2 to RS232 Serial port via P41 pin 3
#define Tx 1                                  // JD1 CPU pin 3 to RS232 Serial port via P47 pin 3

int DataByte = '@';
int cursor_position = 0; 

void setup() {
  pinMode(READ_LED, OUTPUT);                  // RED
  pinMode(WRITE_LED, OUTPUT);                 // GREEN
  pinMode(Tx, OUTPUT);                      // RS232 OUT
  pinMode(Rx, INPUT);                       // RS232 IN

  lcd.begin(16,2);
  lcd.clear();
  lcd.setCursor(0,0);
  lcd.print("RS232 Test ");  
  digitalWrite(WRITE_LED, HIGH);        
  digitalWrite(READ_LED, HIGH);        
  delay(1000);
  Serial.begin(115200,SERIAL_8N1);           // Serial 8 bits, No parity, 2 stop bits
  while(!Serial);
//  Serial.begin(115200);                      // Open USB serial communications as well
//  while(!Serial);
  Serial.print("Initialized the RS232 Serial Interface to 115200 Baud.\r\n");
  Serial.print("Type Characters on PC TTY terminal. They should echo back.\r\n");
  lcd.clear();
  lcd.setCursor(0,0);
  lcd.print("Type characters on");
  lcd.setCursor(0,1);
  lcd.print("PC TTY Terminal");
  delay(3000);
  lcd.clear();
  lcd.setCursor(0,0);
}


void loop() {
 if(Serial.available()) {                       // read from Rx, send back to Tx
     digitalWrite(READ_LED, LOW);        
     delay(5);
     DataByte = Serial.read();
     digitalWrite(READ_LED, HIGH);        
     digitalWrite(WRITE_LED, LOW);        
     delay(10);
     if(cursor_position > 15)
        lcd.scrollDisplayLeft();
     else cursor_position++;
     lcd.print((char)DataByte);  
     Serial.write(DataByte);
     digitalWrite(WRITE_LED, HIGH);        
//     Serial.write(DataByte);
     }       
}
