/*
  S110 Bus byte Read test on the 328 2560 CPU S100 CPU Board
  John Monahan    S100Computers.com     4/21/2018

  The CPU will define the S100 bus port to be read. (Port 01H)
*/

#include <LiquidCrystal.h>
#include <EEPROM.h>

LiquidCrystal lcd(42,47,43,44,45,46);       // CPU pins 42,37,41,40,38,38 (PL7, PL2, PL6, PL5, PL4, PL3)

#define READ_LED 3                            // PE4 CPU pin 6 to LED D2  (GREEN)
#define WRITE_LED 2                           // PE5 CPU pin 7 to LED D3  (RED)  

const int READ_S100_DATA1 = 14;               // PJ1 CPU pin 64 (Output) via P13 9-10
const int S100_DATA1_READY = 19;              // PD2 CPU pin 45 (Input) via P13 3-4
bool READY;
byte x = 0;

void setup() {
  DDRK = 0b11111111;                          // Set CPU pins 89-82 as Outputs (8 bits wide Port Address)
  DDRA = 0b00000000;                          // Set CPU pins 78-71 as Input (8 bits wide)
  PORTA = 0xFF;                               // enable all pullups
  
  pinMode(READ_LED, OUTPUT);
  pinMode(WRITE_LED, OUTPUT);
  pinMode(S100_DATA1_READY, INPUT);
  pinMode(READ_S100_DATA1, OUTPUT);
  
  lcd.begin(16,2);
  lcd.clear();
  lcd.setCursor(0,2);
  lcd.print("Read Port 01H");  
  delay(1000);

  digitalWrite(READ_S100_DATA1, LOW);           // Clear FF U14A    
  digitalWrite(READ_S100_DATA1, HIGH);   
  digitalWrite(WRITE_LED, HIGH);        
  digitalWrite(READ_LED, HIGH);        
  PORTK = 0x01;                                 // Set port address to 01H (CPU Pins 89-82) 
 }


void loop() {
  if (digitalRead(S100_DATA1_READY))
    { 
    lcd.clear();
    lcd.print("READY = TRUE ");
    lcd.setCursor(0,2);
    lcd.print("Port 01H = ");
    digitalWrite(READ_S100_DATA1, LOW);         // latch and hold data bit      
    x = PINA;                                   // Read all a bits (CPU Pins 89-82)
    digitalWrite(READ_S100_DATA1, HIGH);        // we are done, release 74LS374
    lcd.print((char)x);
   digitalWrite(READ_LED, LOW);                 // Flash READ LED  
   delay(500);
    } 
  lcd.clear();
  lcd.print("READY = FALSE");
  lcd.setCursor(0,2);
  lcd.print("Port 01H = ");
  lcd.print((char)x);
  digitalWrite(READ_LED,HIGH);        
  delay(500);
}


