/*
  S110 Bus byte Read (S100 Bus Port 80H) test on the 328 2560 CPU S100 CPU Board using the 2560 CPU
  John Monahan    S100Computers.com     4/21/2018
*/

#include <LiquidCrystal.h>
#include <EEPROM.h>

LiquidCrystal lcd(42,47,43,44,45,46);         // CPU pins 42,37,41,40,38,38 (PL7, PL2, PL6, PL5, PL4, PL3)

#define READ_LED 3                            // PE4 CPU pin 6 to LED D2  (GREEN)
#define WRITE_LED 2                           // PE5 CPU pin 7 to LED D3  (RED)  

const int READ_S100_DATA0 = 48;               // PL1 CPU pin 36 (Output) via P13 13-14
const int S100_DATA0_READY = 21;              // PD0 CPU pin 43 (Input) via P13 7-8
bool READY;
byte x = 0;

void setup() {
  DDRA = 0b00000000;                          // Set CPU pins 78-71 as Input (8 bits wide)
  PORTA = 0xFF;                               // enable all pullups
  
  pinMode(READ_LED, OUTPUT);
  pinMode(WRITE_LED, OUTPUT);
  pinMode(S100_DATA0_READY, INPUT);
  pinMode(READ_S100_DATA0, OUTPUT);
  
  lcd.begin(16,2);
  lcd.clear();
  lcd.setCursor(0,2);
  lcd.print("Read Port 80H");  
  delay(1000);

  digitalWrite(READ_S100_DATA0, LOW);           // Clear FF U14A    
  digitalWrite(READ_S100_DATA0, HIGH);   
  digitalWrite(WRITE_LED, HIGH);        
  digitalWrite(READ_LED, HIGH);        
}


void loop() {
  if (digitalRead(S100_DATA0_READY))
    { 
    lcd.clear();
    lcd.print("READY = TRUE ");
    lcd.setCursor(0,2);
    lcd.print("Port 80H = ");
    digitalWrite(READ_S100_DATA0, LOW);         // latch and hold data bit      
    x = PINA;                                   // Read all a bits (CPU Pins 78-71)
    digitalWrite(READ_S100_DATA0, HIGH);        // we are done, release 74LS374
    lcd.print(x,HEX);
   digitalWrite(READ_LED, LOW);                 // Flash READ LED  
   delay(500);
    } 
  lcd.clear();
  lcd.print("READY = FALSE");
  lcd.setCursor(0,2);
  lcd.print("Port 80H = ");
  lcd.print(x,HEX);
  digitalWrite(READ_LED,HIGH);        
  delay(500);
}


