/*
  S110 Bus bit Read test on the 328 2560 CPU S100 CPU Board
  John Monahan    S100Computers.com     4/21/2018

  Will output data to LCD display and Serial IDE Interface
*/

#include <LiquidCrystal.h>
#include <SPI.h>
#include <EEPROM.h>

LiquidCrystal lcd(8, 9, 7, 6, 5, 4);          // CPU pins 14, 15, 6, 11, 12, 13  (PB0, PB1, PD7, PD6, PD5, PD4 of CPU)

// LEDs showing Red/Write activity 
#define WRITE_LED 3                // 328 CPU Pin5, PD3 
#define READ_LED 2                 // 328 CPU Pin4, PD2 

const int S100_DATA_BIT0 = 14;                // PC0 (PF0 on 2560/Schematic) CPU pin 23 (Input)
const int S100_DATA0_READY = 18;              // PC4 (PF4) CPU pin27 (Input)
const int READ_S100_DATA0 = 19;               // PC5 (PF5 on 2560/Schematic) 328-CPU pin 28 (Output)


void setup() {
  pinMode(READ_LED, OUTPUT);
  pinMode(WRITE_LED, OUTPUT);
  pinMode(S100_DATA0_READY, INPUT);
  pinMode(READ_S100_DATA0, OUTPUT);
  pinMode(S100_DATA_BIT0, INPUT);

  lcd.begin(16,2);
  lcd.clear();
  lcd.print("LCD Initilized.");
  lcd.setCursor(0,2);
  lcd.print(" Read 80H bit 0");
  delay(1000);

  digitalWrite(READ_S100_DATA0, LOW);          // Clear FF     
  digitalWrite(READ_S100_DATA0, HIGH);   
  digitalWrite(WRITE_LED, HIGH);        
}


void loop() {
  bool x;
  lcd.clear();
  if (digitalRead(S100_DATA0_READY))
    { 
    digitalWrite(READ_S100_DATA0, LOW);         // latch and hold data bit      
    x = digitalRead(S100_DATA_BIT0);
    digitalWrite(READ_S100_DATA0, HIGH);        // we are done, release 74LS374
    }
  digitalWrite(READ_LED, !x);        
  lcd.print("80H = XXXXXXX");
  lcd.print(x);
  delay(1000);
}


