/*
  S110 Bus byte Write (by the Arduino CPU)to an S100 bus port on the 328 2560 CPU S100 CPU Board using the 2560 CPU
  John Monahan    S100Computers.com     4/21/2018
*/

#include <LiquidCrystal.h>
#include <EEPROM.h>

LiquidCrystal lcd(42,47,43,44,45,46);       // CPU pins 42,37,41,40,38,38 (PL7, PL2, PL6, PL5, PL4, PL3)

#define READ_LED 3                            // PE4 CPU pin 6 to LED D2  (GREEN)
#define WRITE_LED 2                           // PE5 CPU pin 7 to LED D3  (RED)  

const int WRITE_S100_DATA0 = 49;             // PL0 CPU pin 35 (Output) via P13 15-16
const int S100_DATA0_BUSY = 20;              // PD1 CPU pin 44 (Input) via P13 5-6
bool READY;
byte x = 0;

void setup() {
  DDRC = 0b11111111;                          // Set CPU pins 78-71 as Outputs (8 bits wide)
  
  pinMode(READ_LED, OUTPUT);                  // RED
  pinMode(WRITE_LED, OUTPUT);                 // GREEN
  pinMode(S100_DATA0_BUSY, INPUT);
  pinMode(WRITE_S100_DATA0, OUTPUT);
  
  lcd.begin(16,2);
  lcd.clear();
  lcd.setCursor(0,0);
  lcd.print("Write Port 80H");  
  delay(1000);

  digitalWrite(WRITE_S100_DATA0, LOW);             // Clear FF U14B    
  digitalWrite(WRITE_S100_DATA0, HIGH);   
  digitalWrite(WRITE_LED, HIGH);        
  digitalWrite(READ_LED, HIGH);        
}


void loop() {
      READY = digitalRead(S100_DATA0_BUSY);        
      digitalWrite(WRITE_LED,READY);               // Show status of READY LED  
      if(!READY)
        {                
        lcd.clear();
        lcd.print("80H BUSY = FALSE");
        PORTC = x++;                               // Write all a bits (CPU Pins 53-60)
        digitalWrite(WRITE_S100_DATA0, LOW);       // latch and hold data bit      
        digitalWrite(WRITE_S100_DATA0, HIGH);      // we are done, release 74LS374
        delay(300);                                // Allow time to read LCD display
        } else {
       lcd.setCursor(0,0);
       lcd.print("80H BUSY = TRUE ");
       lcd.setCursor(0,2);
       lcd.print("Next Byte = ");
       lcd.print(PORTC,HEX);
       }
}

