/*
   S110 Bus bit Write (by the Arduino CPU)to an S100 bus port on the 328 2560 CPU S100 CPU Board using the 328 CPU
  John Monahan    S100Computers.com     5/20/2018

  Will output data to LCD display and Serial IDE Interface
*/

#include <LiquidCrystal.h>
#include <SPI.h>
#include <EEPROM.h>

LiquidCrystal lcd(8, 9, 7, 6, 5, 4);          // CPU pins 14, 15, 6, 11, 12, 13  (PB0, PB1, PD7, PD6, PD5, PD4 of CPU)

// LEDs showing Red/Write activity 
#define WRITE_LED 3                           // 328 CPU Pin5, PD3 
#define READ_LED 2                            // 328 CPU Pin4, PD2 

const int WRITE_S100_DATA0 = 15;              // PC1 on CPU pin 24 (Output)
const int S100_DATA_BIT0 = 16;                // PC2 CPU pin 25 (Output)
const int S100_DATA0_BUSY = 17;               // PC3 CPU pin 26 (Input)
bool x;


void setup() {
  Serial.begin(115200);                       // Open serial communications and wait for port to open:
  while (!Serial);                            // wait for serial port to connect. Needed for native USB port only
  Serial.println("Card initialized OK.");
  pinMode(WRITE_LED, OUTPUT);
  pinMode(S100_DATA0_BUSY, INPUT);
  pinMode(WRITE_S100_DATA0, OUTPUT);
  pinMode(S100_DATA_BIT0, OUTPUT);

  lcd.begin(16,2);
  lcd.clear();
  lcd.print("LCD Initilized.");
  lcd.setCursor(0,2);
  lcd.print("Write 80 bit 0");  
  delay(1000);
  digitalWrite(WRITE_S100_DATA0, HIGH);        // Set FF     
  digitalWrite(WRITE_S100_DATA0, LOW);   
  lcd.clear();
}


void loop() {
 digitalWrite(WRITE_LED, HIGH);        
 if((bool)digitalRead(S100_DATA0_BUSY))
    {
     lcd.setCursor(0,0);
     lcd.print("BUSY = HIGH ");
     lcd.setCursor(0,2);
     lcd.print("Read Port 80H  ");
     Serial.println("Read Port 80H.");
    }
  else 
   {
   lcd.clear();
   lcd.print("BUSY = LOW ");
   if(x == HIGH)
      {
      digitalWrite(S100_DATA_BIT0, LOW);         // Latch and hold data bit  
      lcd.setCursor(0,2);
      lcd.print("80H = XXXXXXX1 ");
      Serial.println("80H = XXXXXXX1 ");
     x = LOW;
      }
    else
      { 
      digitalWrite(S100_DATA_BIT0, HIGH);        // Latch and hold data bit  
      lcd.setCursor(0,2);
      lcd.print("80H = XXXXXXX0 ");
      Serial.println("80H = XXXXXXX0 ");
      x = HIGH;
      }
   digitalWrite(WRITE_S100_DATA0, HIGH);         // Reset FF     
   digitalWrite(WRITE_S100_DATA0, LOW);   
   digitalWrite(WRITE_LED, LOW);        
   delay(1000);
   }
}



