/*
  SD card Info test on Arduino 328-2560 S100 Board
  John Monahan S100Computers.com     4/20/2018
*/

#include <LiquidCrystal.h>
#include <SPI.h>                            // include the SD library:
#include <SD.h>

LiquidCrystal lcd(8, 9, 7, 6, 5, 4);        // CPU pins 14, 15, 6, 11, 12, 13  (PB0, PB1, PD7, PD6, PD5, PD4 of CPU)
                                            // PB0, PB1, PH4, PH3, PE3, PG5 on schematic

                                            // set up variables using the SD utility library functions:
Sd2Card card;
SdVolume volume;
SdFile root;

const int chipSelect = 10;

void setup() {
  Serial.begin(115200);                     // Open serial communications and wait for port to open:
  while (!Serial) {
    ;                                       // wait for serial port to connect. Needed for native USB port only
  }

  lcd.begin(16, 2);
  lcd.clear();
  lcd.print("SDCard Info Test");

  Serial.print("\nInitializing SD card...");
  pinMode(10, OUTPUT);
                                             // we'll use the initialization code from the utility libraries
                                             // since we're just testing if the card is working!
  if (!card.init(SPI_HALF_SPEED, chipSelect)) {
    Serial.println("initialization failed. Things to check:");
    Serial.println("* is a card inserted?");
    Serial.println("* is your wiring correct?");
    Serial.println("* did you change the chipSelect pin to match your shield or module?");
    return;
  } else {
    Serial.println("Wiring is correct and a card is present.");
  }

                                             // print the type of card
  Serial.print("\nCard type: ");
  switch (card.type()) {
    case SD_CARD_TYPE_SD1:
      Serial.println("SD1");
      break;
    case SD_CARD_TYPE_SD2:
      Serial.println("SD2");
      break;
    case SD_CARD_TYPE_SDHC:
      Serial.println("SDHC");
      break;
    default:
      Serial.println("Unknown");
  }

                                            // Now we will try to open the 'volume'/'partition' - it should be FAT16 or FAT32
  if (!volume.init(card)) {
    Serial.println("Could not find FAT16/FAT32 partition.\nMake sure you've formatted the card");
    return;
  }

                                            // print the type and size of the first FAT-type volume
  uint32_t volumesize;
  Serial.print("\nVolume type is FAT");
  Serial.println(volume.fatType(), DEC);
  Serial.println();

  volumesize = volume.blocksPerCluster();    // clusters are collections of blocks
  volumesize *= volume.clusterCount();       // we'll have a lot of clusters
  volumesize *= 512;                         // SD card blocks are always 512 bytes
  Serial.print("Volume size (bytes): ");
  Serial.println(volumesize);
  Serial.print("Volume size (Kbytes): ");
  volumesize /= 1024;
  Serial.println(volumesize);
  Serial.print("Volume size (Mbytes): ");
  volumesize /= 1024;
  Serial.println(volumesize);


  Serial.println("\nFiles found on the card (name, date and size in bytes): ");
  root.openRoot(volume);

                                              // list all files in the card with date and size
  root.ls(LS_R | LS_DATE | LS_SIZE);
}


void loop(void) {

}
